@@ -1,13 +1,18 @@
 """bareASGI websocket support"""
 
 from .websocket import WebSocket
+from .websocket_callbacks import (
+    WebSocketRequestCallback,
+    WebSocketMiddlewareCallback
+)
 from .websocket_instance import WebSocketInstance
-from .websocket_request import WebSocketRequest, WebSocketRequestCallback
+from .websocket_request import WebSocketRequest
 from .websocket_router import WebSocketRouter
 
 __all__ = [
     'WebSocket',
     'WebSocketInstance',
+    'WebSocketMiddlewareCallback',
     'WebSocketRequest',
     'WebSocketRequestCallback',
     'WebSocketRouter'
